# viral
Acquiring and analyzing covid-19 (coronavirus) statistics data

To install:	```pip install viral```

Pypi: https://pypi.org/project/viral/

# What for?

![image](https://user-images.githubusercontent.com/1906276/126843872-5d42ba43-faa3-4d55-9d33-c44b50a08655.png)

This module will help you get and prepare the data behind these:

- Country cases: https://public.flourish.studio/visualisation/1704821/
- Country Deaths: https://public.flourish.studio/visualisation/1705644/
- US State cases: https://public.flourish.studio/visualisation/1794768/
- US State Deaths: https://public.flourish.studio/visualisation/1794797/

- Country cases per capita: https://public.flourish.studio/visualisation/6812015/
- Country deaths per capita: https://public.flourish.studio/visualisation/6812118/
- US State Cases per capita: https://public.flourish.studio/visualisation/6811967/
- US State deaths per capita: https://public.flourish.studio/visualisation/6812165

You'll need a kaggle account to get the data (or download it manually).

You'll need a flourish account to make the bar graph races.

Both accounts are free.

